@@ -21,6 +21,7 @@ const (
 	headerForwardedUser         = "X-Forwarded-User"
 	headerForwardedRoles        = "X-Forwarded-Roles"
 	headerForwardedNamespace    = "X-OCP-NS"
+	headerForwardedNamespaceUid = "X-OCP-NSUID"
 	headerXForwardedAccessToken = "X-Forwarded-Access-Token"
 )
 
@@ -81,14 +82,20 @@ func (auth *authorizationHandler) Process(req *http.Request) (*http.Request, err
 		projects := rolesProjects.projects
 
 		projectNames := []string{}
+		projectUIDs := []string{}
 		for _, project := range projects {
 			projectNames = append(projectNames, fmt.Sprintf("%q", project.Name))
+			projectUIDs = append(projectUIDs, project.UUID)
 		}
 
 		req.Header.Add(headerForwardedNamespace, strings.Join(projectNames, ","))
+		req.Header.Add(headerForwardedNamespaceUid, strings.Join(projectUIDs, ","))
 		ctx = context.WithValue(ctx, handlers.ProjectsKey, projects)
 
 		var roles []string
+		if auth.config.AuthDefaultRole != "" {
+			roles = append(roles, auth.config.AuthDefaultRole)
+		}
 
 		for name := range auth.config.AuthBackEndRoles {
 			if _, ok := rolesProjects.roles[name]; ok {
@@ -96,11 +103,6 @@ func (auth *authorizationHandler) Process(req *http.Request) (*http.Request, err
 			}
 		}
 
-		if len(roles) == 0 && auth.config.AuthDefaultRole != "" {
-			log.Debugf("User has no roles. Adding default role: %s", auth.config.AuthDefaultRole)
-			roles = append(roles, auth.config.AuthDefaultRole)
-		}
-
 		rs := sets.NewString(roles...)
 		if rs.Has(auth.config.AuthAdminRole) {
 			log.Debugf("User has the configurated admin role %v. Removing all other roles.", auth.config.AuthAdminRole)
@@ -135,6 +137,7 @@ func sanitizeHeaders(req *http.Request) {
 	req.Header.Del(headerForwardedRoles)
 	req.Header.Del(headerForwardedUser)
 	req.Header.Del(headerForwardedNamespace)
+	req.Header.Del(headerForwardedNamespaceUid)
 	req.Header.Del(headerXForwardedAccessToken)
 }
 
